package com.ruoyi.system.service.impl;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.system.entity.DragTable;
import com.ruoyi.system.entity.DragTableGroup;
import com.ruoyi.system.entity.vo.DragTableGroupVo;
import com.ruoyi.system.entity.vo.DragTableVo;
import com.ruoyi.system.mapper.DragTableGroupMapper;
import com.ruoyi.system.mapper.DragTableMapper;
import com.ruoyi.system.service.IDragTableGroupService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

/**
 * @author hmc
 * @date 2023-11-01 14:27
 * @Description:
 */

@Service
public class DragTableGroupServiceImpl implements IDragTableGroupService {

    @Autowired
    private DragTableGroupMapper dragTableGroupMapper;

    @Autowired
    private DragTableMapper dragTableMapper;

    @Autowired
    private DragTableServiceImpl dragTableService;

    /**
     * 查询拖拽格组
     *
     * @param id 拖拽格组主键
     * @return 拖拽格组
     */
    @Override
    public DragTableGroup selectDragTableGroupById(Long id)
    {
        return dragTableGroupMapper.selectDragTableGroupById(id);
    }

    /**
     * 查询拖拽格组列表
     *
     * @param dragTableGroup 拖拽格组
     * @return 拖拽格组
     */
    @Override
    public List<DragTableGroup> selectDragTableGroupList(DragTableGroup dragTableGroup)
    {
        return dragTableGroupMapper.selectDragTableGroupList(dragTableGroup);
    }

    /**
     * 新增拖拽格组
     *
     * @param dragTableGroupVo 拖拽格组
     * @return 结果
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public int insertDragTableGroup(DragTableGroupVo dragTableGroupVo)
    {
        //表格组实体类拷贝数据
        DragTableGroup dragTableGroup=new DragTableGroup();
        BeanUtils.copyProperties(dragTableGroupVo,dragTableGroup);
        //添加动态表格列表
        List<DragTableVo> dragTables = dragTableGroupVo.getDragTables();
        dragTables.forEach(item->{
            dragTableService.addDragTable(item);
        });
        return dragTableGroupMapper.insertDragTableGroup(dragTableGroup);
    }
    /**
     * 修改拖拽格组
     *
     * @param dragTableGroup 拖拽格组
     * @return 结果
     */
    @Override
    public int updateDragTableGroup(DragTableGroup dragTableGroup)
    {
        dragTableGroup.setUpdateTime(DateUtils.getNowDate());
        return dragTableGroupMapper.updateDragTableGroup(dragTableGroup);
    }

    /**
     * 批量删除拖拽格组
     *
     * @param ids 需要删除的拖拽格组主键
     * @return 结果
     */
    @Override
    public int deleteDragTableGroupByIds(Long[] ids)
    {
        return dragTableGroupMapper.deleteDragTableGroupByIds(ids);
    }

    /**
     * 删除拖拽格组信息
     *
     * @param id 拖拽格组主键
     * @return 结果
     */
    @Override
    public int deleteDragTableGroupById(Long id)
    {
        return dragTableGroupMapper.deleteDragTableGroupById(id);
    }
}
